# ForwardingAddress

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**forwarding_email** | **str** | An email address to which messages can be forwarded. | [optional] 
**verification_status** | **str** | Indicates whether this address has been verified and is usable for forwarding. Read-only. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

